import { N_CELLS_PER_SLAVE, N_TEMP_SENSORS_PER_SLAVE } from './defs';
import type { SlaveLog, SlaveLogLastCell, SlaveLogTemperature, SlaveLogVoltage } from './messages';

export class SlaveLogData {
	voltages: number[];
	temperatures: number[];
	failedTempSensors: number;

	constructor() {
		this.voltages = [];
		for (let i = 0; i < N_CELLS_PER_SLAVE; i++) {
			this.voltages.push(0);
		}
		this.temperatures = [];
		for (let i = 0; i < N_TEMP_SENSORS_PER_SLAVE; i++) {
			this.temperatures.push(0);
		}
		this.failedTempSensors = 0;
	}

	handleMsg(msg: SlaveLog) {
		switch (msg.logType) {
			case 'voltage': {
				const voltMsg = msg as SlaveLogVoltage;
				for (let i = 0; i < 4; i++) {
					this.voltages[voltMsg.startIndex + i] = voltMsg.voltages[i];
				}
				break;
			}
			case 'lastCell': {
				const lastMsg = msg as SlaveLogLastCell;
				this.voltages[this.voltages.length - 1] = lastMsg.voltage;
				this.failedTempSensors = lastMsg.failed_temp_sensors;
				break;
			}
			case 'temperature': {
				const tempMsg = msg as SlaveLogTemperature;
				for (let i = 0; i < 8; i++) {
					this.temperatures[tempMsg.startIndex + i] = tempMsg.temperatures[i];
				}
				break;
			}
			default: {
				console.error('Unknwon slave log type', msg.logType);
			}
		}
	}
}
